setWarningNotificationOnKill static method
When the app is killed, all the processes are terminated so the alarm may never ring. By default, to warn the user, a notification is shown at the moment he kills the app. This methods allows you to customize this notification content.
title default value is Your alarm may not ring
body default value is You killed the app. Please reopen so your alarm can ring.
Implementation
static Future<void> setWarningNotificationOnKill(
String title,
String body,
) async {
if (iOS) await IOSAlarm().setWarningNotificationOnKill(title, body);
if (android) await AndroidAlarm().setWarningNotificationOnKill(title, body);
}